@@ -25,13 +25,17 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
 
+	"github.com/GoogleContainerTools/skaffold/cmd/skaffold/app/flags"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 )
 
 var (
-	showBuild        bool
-	renderOutputPath string
+	showBuild                 bool
+	renderOutputPath          string
+	renderFromBuildOutputFile flags.BuildOutputFileFlag
+	offline                   bool
 )
 
 // NewCmdRender describes the CLI command to build artifacts render Kubernetes manifests.
@@ -42,6 +46,8 @@ func NewCmdRender() *cobra.Command {
 		WithCommonFlags().
 		WithFlags(func(f *pflag.FlagSet) {
 			f.BoolVar(&showBuild, "loud", false, "Show the build logs and output")
+			f.VarP(&renderFromBuildOutputFile, "build-artifacts", "a", "File containing build result from a previous 'skaffold build --file-output'")
+			f.BoolVar(&offline, "offline", false, `Do not connect to Kubernetes API server for manifest creation and validation. This is helpful when no Kubernetes cluster is available (e.g. GitOps model). No metadata.namespace attribute is injected in this case - the manifest content does not get changed.`)
 			f.StringVar(&renderOutputPath, "output", "", "file to write rendered manifests to")
 			f.StringVar(&opts.DigestSource, "digest-source", "local", "Set to 'local' to build images locally and use digests from built images; Set to 'remote' to resolve the digest of images by tag from the remote registry; Set to 'none' to use tags directly from the Kubernetes manifests")
 		}).
@@ -55,11 +61,19 @@ func doRender(ctx context.Context, out io.Writer) error {
 	}
 
 	return withRunner(ctx, func(r runner.Runner, config *latest.SkaffoldConfig) error {
-		bRes, err := r.BuildAndTest(ctx, buildOut, targetArtifacts(opts, config))
-		if err != nil {
-			return fmt.Errorf("executing build: %w", err)
+		var bRes []build.Artifact
+
+		if renderFromBuildOutputFile.String() != "" {
+			bRes = renderFromBuildOutputFile.BuildArtifacts()
+		} else {
+			var err error
+			bRes, err = r.BuildAndTest(ctx, buildOut, targetArtifacts(opts, config))
+			if err != nil {
+				return fmt.Errorf("executing build: %w", err)
+			}
 		}
-		if err := r.Render(ctx, out, bRes, renderOutputPath); err != nil {
+
+		if err := r.Render(ctx, out, bRes, offline, renderOutputPath); err != nil {
 			return fmt.Errorf("rendering manifests: %w", err)
 		}
 		return nil
