@@ -77,8 +77,9 @@ type Definition struct {
 	Examples             []string               `json:"examples,omitempty"`
 	Enum                 []string               `json:"enum,omitempty"`
 
-	inlines []*Definition
-	tags    string
+	inlines  []*Definition
+	tags     string
+	skipTrim bool
 }
 
 func main() {
@@ -238,7 +239,8 @@ func (g *schemaGenerator) newDefinition(name string, t ast.Expr, comment string,
 			if strings.Contains(field.Tag.Value, "inline") {
 				def.PreferredOrder = append(def.PreferredOrder, "<inline>")
 				def.inlines = append(def.inlines, &Definition{
-					Ref: defPrefix + field.Type.(*ast.Ident).Name,
+					Ref:      defPrefix + field.Type.(*ast.Ident).Name,
+					skipTrim: strings.Contains(field.Tag.Value, "skipTrim"),
 				})
 				continue
 			}
@@ -354,6 +356,9 @@ func (g *schemaGenerator) Apply(inputPath string) ([]byte, error) {
 		}
 
 		for _, inlineStruct := range def.inlines {
+			if inlineStruct.skipTrim {
+				continue
+			}
 			ref := strings.TrimPrefix(inlineStruct.Ref, defPrefix)
 			inlines = append(inlines, ref)
 		}
@@ -435,7 +440,13 @@ func (g *schemaGenerator) Apply(inputPath string) ([]byte, error) {
 	}
 
 	for _, ref := range inlines {
-		delete(definitions, ref)
+		existingDef, ok := definitions[ref]
+		if !ok {
+			continue
+		}
+		if !existingDef.skipTrim {
+			delete(definitions, ref)
+		}
 	}
 
 	schema := Schema{
