@@ -30,20 +30,82 @@ import (
 
 	"github.com/GoogleContainerTools/skaffold/integration/skaffold"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner/runcontext"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
+func TestKubectlRenderOutput(t *testing.T) {
+	if testing.Short() || RunOnGCP() {
+		t.Skip("skipping kind integration test")
+	}
+
+	test := struct {
+		description string
+		builds      []build.Artifact
+		renderPath  string
+		input       string
+		expectedOut string
+	}{
+		description: "write rendered manifest to provided filepath",
+		builds: []build.Artifact{
+			{
+				ImageName: "gcr.io/k8s-skaffold/skaffold",
+				Tag:       "gcr.io/k8s-skaffold/skaffold:test",
+			},
+		},
+		renderPath: "./test-output",
+		input: `apiVersion: v1
+kind: Pod
+spec:
+  containers:
+  - image: gcr.io/k8s-skaffold/skaffold
+    name: skaffold
+`,
+		expectedOut: `apiVersion: v1
+kind: Pod
+metadata:
+  namespace: default
+spec:
+  containers:
+  - image: gcr.io/k8s-skaffold/skaffold:test
+    name: skaffold
+`}
+
+	testutil.Run(t, test.description, func(t *testutil.T) {
+		t.NewTempDir().
+			Write("deployment.yaml", test.input).
+			Chdir()
+		deployer := deploy.NewKubectlDeployer(&runcontext.RunContext{
+			WorkingDir: ".",
+			Cfg: latest.Pipeline{
+				Deploy: latest.DeployConfig{
+					DeployType: latest.DeployType{
+						KubectlDeploy: &latest.KubectlDeploy{
+							Manifests: []string{"deployment.yaml"},
+						},
+					},
+				},
+			},
+		}, nil)
+		var b bytes.Buffer
+		err := deployer.Render(context.Background(), &b, test.builds, false, test.renderPath)
+
+		t.CheckNoError(err)
+		dat, err := ioutil.ReadFile(test.renderPath)
+		t.CheckNoError(err)
+
+		t.CheckDeepEqual(test.expectedOut, string(dat))
+	})
+}
+
 func TestKubectlRender(t *testing.T) {
 	MarkIntegrationTest(t, CanRunWithoutGcp)
 
 	tests := []struct {
 		description string
 		builds      []build.Artifact
-		labels      []deploy.Labeller
 		input       string
 		expectedOut string
 	}{
@@ -55,7 +117,6 @@ func TestKubectlRender(t *testing.T) {
 					Tag:       "gcr.io/k8s-skaffold/skaffold:test",
 				},
 			},
-			labels: []deploy.Labeller{},
 			input: `apiVersion: v1
 kind: Pod
 metadata:
@@ -68,8 +129,6 @@ spec:
 			expectedOut: `apiVersion: v1
 kind: Pod
 metadata:
-  labels:
-    skaffold.dev/deployer: kubectl
   name: my-pod-123
   namespace: default
 spec:
@@ -90,7 +149,6 @@ spec:
 					Tag:       "gcr.io/project/image2:tag2",
 				},
 			},
-			labels: []deploy.Labeller{},
 			input: `apiVersion: v1
 kind: Pod
 metadata:
@@ -105,8 +163,6 @@ spec:
 			expectedOut: `apiVersion: v1
 kind: Pod
 metadata:
-  labels:
-    skaffold.dev/deployer: kubectl
   name: my-pod-123
   namespace: default
 spec:
@@ -150,8 +206,6 @@ spec:
 			expectedOut: `apiVersion: v1
 kind: Pod
 metadata:
-  labels:
-    skaffold.dev/deployer: kubectl
   name: my-pod-123
   namespace: default
 spec:
@@ -162,8 +216,6 @@ spec:
 apiVersion: v1
 kind: Pod
 metadata:
-  labels:
-    skaffold.dev/deployer: kubectl
   name: my-pod-456
   namespace: default
 spec:
@@ -190,12 +242,9 @@ spec:
 						},
 					},
 				},
-				Opts: config.SkaffoldOptions{
-					AddSkaffoldLabels: true,
-				},
-			})
+			}, nil)
 			var b bytes.Buffer
-			err := deployer.Render(context.Background(), &b, test.builds, test.labels, false, "")
+			err := deployer.Render(context.Background(), &b, test.builds, false, "")
 
 			t.CheckNoError(err)
 			t.CheckDeepEqual(test.expectedOut, b.String())
@@ -211,7 +260,6 @@ func TestHelmRender(t *testing.T) {
 	tests := []struct {
 		description  string
 		builds       []build.Artifact
-		labels       []deploy.Labeller
 		helmReleases []latest.HelmRelease
 		expectedOut  string
 	}{
@@ -223,7 +271,6 @@ func TestHelmRender(t *testing.T) {
 					Tag:       "gke-loadbalancer:test",
 				},
 			},
-			labels: []deploy.Labeller{},
 			helmReleases: []latest.HelmRelease{{
 				Name:      "gke_loadbalancer",
 				ChartPath: "testdata/gke_loadbalancer/loadbalancer-helm",
@@ -282,7 +329,6 @@ spec:
 					Tag:       "gcr.io/k8s-skaffold/skaffold-helm:sha256-nonsenslettersandnumbers",
 				},
 			},
-			labels: []deploy.Labeller{},
 			helmReleases: []latest.HelmRelease{{
 				Name:      "skaffold-helm",
 				ChartPath: "testdata/helm/skaffold-helm",
@@ -381,9 +427,9 @@ spec:
 						},
 					},
 				},
-			})
+			}, nil)
 			var b bytes.Buffer
-			err := deployer.Render(context.Background(), &b, test.builds, test.labels, true, "")
+			err := deployer.Render(context.Background(), &b, test.builds, true, "")
 
 			t.CheckNoError(err)
 			t.CheckDeepEqual(test.expectedOut, b.String())
@@ -530,12 +576,7 @@ kind: Pod
 metadata:
   labels:
     app.kubernetes.io/managed-by: SOMEDYNAMICVALUE
-    skaffold.dev/builder: local
-    skaffold.dev/cleanup: "true"
-    skaffold.dev/deployer: kubectl
-    skaffold.dev/docker-api-version: SOMEDYNAMICVALUE
     skaffold.dev/run-id: SOMEDYNAMICVALUE
-    skaffold.dev/tag-policy: git-commit
   name: my-pod-123
 spec:
   containers:
@@ -638,12 +679,7 @@ kind: Pod
 metadata:
   labels:
     app.kubernetes.io/managed-by: SOMEDYNAMICVALUE
-    skaffold.dev/builder: local
-    skaffold.dev/cleanup: "true"
-    skaffold.dev/deployer: kustomize
-    skaffold.dev/docker-api-version: SOMEDYNAMICVALUE
     skaffold.dev/run-id: SOMEDYNAMICVALUE
-    skaffold.dev/tag-policy: git-commit
     this-is-from: kustomization.yaml
   name: my-pod-123
 spec:
