@@ -18,6 +18,7 @@ package config
 
 import (
 	"strings"
+	"time"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 )
@@ -29,6 +30,13 @@ type PortForwardOptions struct {
 	ForwardPods bool
 }
 
+// WaitForDeletions configures the wait for pending deletions.
+type WaitForDeletions struct {
+	Max     time.Duration
+	Delay   time.Duration
+	Enabled bool
+}
+
 // SkaffoldOptions are options that are set by command line arguments not included
 // in the config file itself
 type SkaffoldOptions struct {
@@ -48,6 +56,7 @@ type SkaffoldOptions struct {
 	AutoSync              bool
 	AutoDeploy            bool
 	RenderOnly            bool
+	RenderOutput          string
 	ProfileAutoActivation bool
 	DryRun                bool
 	SkipRender            bool
@@ -72,6 +81,7 @@ type SkaffoldOptions struct {
 	TargetImages       []string
 	Profiles           []string
 	InsecureRegistries []string
+	Muted              Muted
 	Command            string
 	RPCPort            int
 	RPCHTTPPort        int
@@ -80,6 +90,8 @@ type SkaffoldOptions struct {
 	// remove minikubeProfile from here and instead detect it by matching the
 	// kubecontext API Server to minikube profiles
 	MinikubeProfile string
+
+	WaitForDeletions WaitForDeletions
 }
 
 // Prune returns true iff the user did NOT specify the --no-prune flag,
