@@ -56,6 +56,7 @@ import (
 	"fmt"
 	"strings"
 
+	shell "github.com/kballard/go-shellquote"
 	"github.com/sirupsen/logrus"
 	appsv1 "k8s.io/api/apps/v1"
 	batchv1 "k8s.io/api/batch/v1"
@@ -327,15 +328,62 @@ func transformContainer(container *v1.Container, config imageConfiguration, port
 		config.arguments = container.Args
 	}
 
-	// Buildpack-generated images require special handling
+	// Apply command-line unwrapping for buildpack images and images using `sh -c`-style command-lines
+	next := func(container *v1.Container, config imageConfiguration) (ContainerDebugConfiguration, string, error) {
+		return performContainerTransform(container, config, portAlloc)
+	}
 	if _, found := config.labels["io.buildpacks.stack.id"]; found && len(config.entrypoint) > 0 && config.entrypoint[0] == "/cnb/lifecycle/launcher" {
-		next := func(container *v1.Container, config imageConfiguration) (ContainerDebugConfiguration, string, error) {
-			return performContainerTransform(container, config, portAlloc)
-		}
 		return updateForCNBImage(container, config, next)
 	}
+	return updateForShDashC(container, config, next)
+}
 
-	return performContainerTransform(container, config, portAlloc)
+func updateForShDashC(container *v1.Container, ic imageConfiguration, transformer func(*v1.Container, imageConfiguration) (ContainerDebugConfiguration, string, error)) (ContainerDebugConfiguration, string, error) {
+	var rewriter func([]string)
+	copy := ic
+	switch {
+	// Case 1: entrypoint = ["/bin/sh", "-c"], arguments = ["<cmd-line>", args ...]
+	case len(ic.entrypoint) == 2 && len(ic.arguments) > 0 && isShDashC(ic.entrypoint[0], ic.entrypoint[1]):
+		if split, err := shell.Split(ic.arguments[0]); err == nil {
+			copy.entrypoint = split
+			copy.arguments = nil
+			rewriter = func(rewrite []string) {
+				container.Command = nil // inherit from container
+				container.Args = append([]string{shJoin(rewrite)}, ic.arguments[1:]...)
+			}
+		}
+
+	// Case 2: entrypoint = ["/bin/sh", "-c", "<cmd-line>", args...], arguments = [args ...]
+	case len(ic.entrypoint) > 2 && isShDashC(ic.entrypoint[0], ic.entrypoint[1]):
+		if split, err := shell.Split(ic.entrypoint[2]); err == nil {
+			copy.entrypoint = split
+			copy.arguments = nil
+			rewriter = func(rewrite []string) {
+				container.Command = append([]string{ic.entrypoint[0], ic.entrypoint[1], shJoin(rewrite)}, ic.entrypoint[3:]...)
+			}
+		}
+
+	// Case 3: entrypoint = [] or an entrypoint launcher (and so ignored), arguments = ["/bin/sh", "-c", "<cmd-line>", args...]
+	case (len(ic.entrypoint) == 0 || isEntrypointLauncher(ic.entrypoint)) && len(ic.arguments) > 2 && isShDashC(ic.arguments[0], ic.arguments[1]):
+		if split, err := shell.Split(ic.arguments[2]); err == nil {
+			copy.entrypoint = split
+			copy.arguments = nil
+			rewriter = func(rewrite []string) {
+				container.Command = nil
+				container.Args = append([]string{ic.arguments[0], ic.arguments[1], shJoin(rewrite)}, ic.arguments[3:]...)
+			}
+		}
+	}
+
+	c, image, err := transformer(container, copy)
+	if err == nil && rewriter != nil && container.Command != nil {
+		rewriter(container.Command)
+	}
+	return c, image, err
+}
+
+func isShDashC(cmd, arg string) bool {
+	return (cmd == "/bin/sh" || cmd == "/bin/bash") && arg == "-c"
 }
 
 func performContainerTransform(container *v1.Container, config imageConfiguration, portAlloc portAllocator) (ContainerDebugConfiguration, string, error) {
