@@ -27,14 +27,13 @@ import (
 	"strings"
 
 	"github.com/segmentio/textio"
+	yamlv3 "gopkg.in/yaml.v3"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/color"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	deploy "github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/kubectl"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/event"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubectl"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner/runcontext"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
@@ -48,6 +47,18 @@ var (
 	basePath             = "base"
 )
 
+// kustomization is the content of a kustomization.yaml file.
+type kustomization struct {
+	Bases                 []string              `yaml:"bases"`
+	Resources             []string              `yaml:"resources"`
+	Patches               []patchWrapper        `yaml:"patches"`
+	PatchesStrategicMerge []strategicMergePatch `yaml:"patchesStrategicMerge"`
+	CRDs                  []string              `yaml:"crds"`
+	PatchesJSON6902       []patchJSON6902       `yaml:"patchesJson6902"`
+	ConfigMapGenerator    []configMapGenerator  `yaml:"configMapGenerator"`
+	SecretGenerator       []secretGenerator     `yaml:"secretGenerator"`
+}
+
 type patchPath struct {
 	Path  string `yaml:"path"`
 	Patch string `yaml:"patch"`
@@ -57,16 +68,9 @@ type patchWrapper struct {
 	*patchPath
 }
 
-// kustomization is the content of a kustomization.yaml file.
-type kustomization struct {
-	Bases                 []string             `yaml:"bases"`
-	Resources             []string             `yaml:"resources"`
-	Patches               []patchWrapper       `yaml:"patches"`
-	PatchesStrategicMerge []string             `yaml:"patchesStrategicMerge"`
-	CRDs                  []string             `yaml:"crds"`
-	PatchesJSON6902       []patchJSON6902      `yaml:"patchesJson6902"`
-	ConfigMapGenerator    []configMapGenerator `yaml:"configMapGenerator"`
-	SecretGenerator       []secretGenerator    `yaml:"secretGenerator"`
+type strategicMergePatch struct {
+	Path  string
+	Patch string
 }
 
 type patchJSON6902 struct {
@@ -91,46 +95,29 @@ type KustomizeDeployer struct {
 
 	kubectl            deploy.CLI
 	insecureRegistries map[string]bool
-	BuildArgs          []string
+	labels             map[string]string
 	globalConfig       string
-	addSkaffoldLabels  bool
 }
 
-func NewKustomizeDeployer(runCtx *runcontext.RunContext) *KustomizeDeployer {
+func NewKustomizeDeployer(runCtx *runcontext.RunContext, labels map[string]string) *KustomizeDeployer {
 	return &KustomizeDeployer{
-		KustomizeDeploy: runCtx.Cfg.Deploy.KustomizeDeploy,
-		kubectl: deploy.CLI{
-			CLI:         kubectl.NewFromRunContext(runCtx),
-			Flags:       runCtx.Cfg.Deploy.KustomizeDeploy.Flags,
-			ForceDeploy: runCtx.Opts.Force,
-		},
-		insecureRegistries: runCtx.InsecureRegistries,
-		BuildArgs:          runCtx.Cfg.Deploy.KustomizeDeploy.BuildArgs,
-		globalConfig:       runCtx.Opts.GlobalConfig,
-		addSkaffoldLabels:  runCtx.Opts.AddSkaffoldLabels,
-	}
-}
-
-// Labels returns the labels specific to kustomize.
-func (k *KustomizeDeployer) Labels() map[string]string {
-	return map[string]string{
-		constants.Labels.Deployer: "kustomize",
+		KustomizeDeploy:    runCtx.Pipeline().Deploy.KustomizeDeploy,
+		kubectl:            deploy.NewCLI(runCtx, runCtx.Pipeline().Deploy.KustomizeDeploy.Flags),
+		insecureRegistries: runCtx.GetInsecureRegistries(),
+		globalConfig:       runCtx.GlobalConfig(),
+		labels:             labels,
 	}
 }
 
 // Deploy runs `kubectl apply` on the manifest generated by kustomize.
-func (k *KustomizeDeployer) Deploy(ctx context.Context, out io.Writer, builds []build.Artifact, labellers []Labeller) *Result {
-	event.DeployInProgress()
-
-	manifests, err := k.renderManifests(ctx, out, builds, labellers)
+func (k *KustomizeDeployer) Deploy(ctx context.Context, out io.Writer, builds []build.Artifact) ([]string, error) {
+	manifests, err := k.renderManifests(ctx, out, builds)
 	if err != nil {
-		event.DeployFailed(err)
-		return NewDeployErrorResult(err)
+		return nil, err
 	}
 
 	if len(manifests) == 0 {
-		event.DeployComplete()
-		return NewDeploySuccessResult(nil)
+		return nil, nil
 	}
 
 	namespaces, err := manifests.CollectNamespaces()
@@ -139,16 +126,18 @@ func (k *KustomizeDeployer) Deploy(ctx context.Context, out io.Writer, builds []
 			"This might cause port-forward and deploy health-check to fail: %w", err))
 	}
 
-	if err := k.kubectl.Apply(ctx, textio.NewPrefixWriter(out, " - "), manifests); err != nil {
-		event.DeployFailed(err)
-		return NewDeployErrorResult(fmt.Errorf("kubectl error: %w", err))
+	if err := k.kubectl.WaitForDeletions(ctx, textio.NewPrefixWriter(out, " - "), manifests); err != nil {
+		return nil, err
 	}
 
-	event.DeployComplete()
-	return NewDeploySuccessResult(namespaces)
+	if err := k.kubectl.Apply(ctx, textio.NewPrefixWriter(out, " - "), manifests); err != nil {
+		return nil, err
+	}
+
+	return namespaces, nil
 }
 
-func (k *KustomizeDeployer) renderManifests(ctx context.Context, out io.Writer, builds []build.Artifact, labellers []Labeller) (deploy.ManifestList, error) {
+func (k *KustomizeDeployer) renderManifests(ctx context.Context, out io.Writer, builds []build.Artifact) (deploy.ManifestList, error) {
 	if err := k.kubectl.CheckVersion(ctx); err != nil {
 		color.Default.Fprintln(out, "kubectl client version:", k.kubectl.Version(ctx))
 		color.Default.Fprintln(out, err)
@@ -180,12 +169,7 @@ func (k *KustomizeDeployer) renderManifests(ctx context.Context, out io.Writer,
 		}
 	}
 
-	manifests, err = manifests.SetLabels(merge(k.addSkaffoldLabels, k, labellers...))
-	if err != nil {
-		return nil, fmt.Errorf("setting labels in manifests: %w", err)
-	}
-
-	return manifests, nil
+	return manifests.SetLabels(k.labels)
 }
 
 // Cleanup deletes what was deployed by calling Deploy.
@@ -215,14 +199,27 @@ func (k *KustomizeDeployer) Dependencies() ([]string, error) {
 	return deps.toList(), nil
 }
 
-func (k *KustomizeDeployer) Render(ctx context.Context, out io.Writer, builds []build.Artifact, labellers []Labeller, offline bool, filepath string) error {
-	manifests, err := k.renderManifests(ctx, out, builds, labellers)
+func (k *KustomizeDeployer) Render(ctx context.Context, out io.Writer, builds []build.Artifact, offline bool, filepath string) error {
+	manifests, err := k.renderManifests(ctx, out, builds)
 	if err != nil {
 		return err
 	}
 	return outputRenderedManifests(manifests.String(), filepath, out)
 }
 
+// Values of `patchesStrategicMerge` can be either:
+// + a file path, referenced as a plain string
+// + an inline patch referenced as a string literal
+func (p *strategicMergePatch) UnmarshalYAML(node *yamlv3.Node) error {
+	if node.Style == 0 || node.Style == yamlv3.DoubleQuotedStyle || node.Style == yamlv3.SingleQuotedStyle {
+		p.Path = node.Value
+	} else {
+		p.Patch = node.Value
+	}
+
+	return nil
+}
+
 // UnmarshalYAML implements JSON unmarshalling by reading an inline yaml fragment.
 func (p *patchWrapper) UnmarshalYAML(unmarshal func(interface{}) error) (err error) {
 	pp := &patchPath{}
@@ -281,16 +278,26 @@ func dependenciesForKustomization(dir string) ([]string, error) {
 		}
 	}
 
-	deps = append(deps, util.AbsolutePaths(dir, content.PatchesStrategicMerge)...)
+	for _, patch := range content.PatchesStrategicMerge {
+		if patch.Path != "" {
+			deps = append(deps, filepath.Join(dir, patch.Path))
+		}
+	}
+
 	deps = append(deps, util.AbsolutePaths(dir, content.CRDs)...)
+
 	for _, patch := range content.Patches {
 		if patch.Path != "" {
 			deps = append(deps, filepath.Join(dir, patch.Path))
 		}
 	}
+
 	for _, jsonPatch := range content.PatchesJSON6902 {
-		deps = append(deps, filepath.Join(dir, jsonPatch.Path))
+		if jsonPatch.Path != "" {
+			deps = append(deps, filepath.Join(dir, jsonPatch.Path))
+		}
 	}
+
 	for _, generator := range content.ConfigMapGenerator {
 		deps = append(deps, util.AbsolutePaths(dir, generator.Files)...)
 		envs := generator.Envs
@@ -299,6 +306,7 @@ func dependenciesForKustomization(dir string) ([]string, error) {
 		}
 		deps = append(deps, util.AbsolutePaths(dir, envs)...)
 	}
+
 	for _, generator := range content.SecretGenerator {
 		deps = append(deps, util.AbsolutePaths(dir, generator.Files)...)
 		envs := generator.Envs
