@@ -40,7 +40,6 @@ const (
 
 // Runner is responsible for running the skaffold build, test and deploy config.
 type Runner interface {
-	DiagnoseArtifacts(context.Context, io.Writer) error
 	Dev(context.Context, io.Writer, []*latest.Artifact) error
 	ApplyDefaultRepo(tag string) (string, error)
 	BuildAndTest(context.Context, io.Writer, []*latest.Artifact) ([]build.Artifact, error)
@@ -63,13 +62,12 @@ type SkaffoldRunner struct {
 	monitor  filemon.Monitor
 	listener Listener
 
-	kubectlCLI      *kubectl.CLI
-	cache           cache.Cache
-	changeSet       changeSet
-	runCtx          *runcontext.RunContext
-	labellers       []deploy.Labeller
-	defaultLabeller *deploy.DefaultLabeller
-	builds          []build.Artifact
+	kubectlCLI *kubectl.CLI
+	cache      cache.Cache
+	changeSet  changeSet
+	runCtx     *runcontext.RunContext
+	labeller   *deploy.DefaultLabeller
+	builds     []build.Artifact
 
 	// podSelector is used to determine relevant pods for logging and portForwarding
 	podSelector *kubernetes.ImageList
